<?php
session_start();
require_once 'includes/db_connect.php';

if (!isset($_SESSION['user_id'])) {
    die("You must be logged in to edit your profile.");
}

$user_id = $_SESSION['user_id'];
$sql = "SELECT * FROM users WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows == 1) {
    $user = $result->fetch_assoc();
} else {
    die("User not found.");
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Edit Profile</title>
    <link rel="stylesheet" href="style.css">
    <style>
        body {
            background: #000;
            color: #fff;
            font-family: 'Arial', sans-serif;
            margin: 0;
            padding: 0;
        }

        .edit-profile-container {
            max-width: 500px;
            margin: 50px auto;
            background: #111;
            border-radius: 10px;
            padding: 30px;
            box-shadow: 0 0 20px rgba(255,255,255,0.05);
        }

        h2 {
            margin-top: 0;
            text-align: center;
            font-weight: 400;
        }

        form label {
            display: block;
            margin: 15px 0 5px;
            font-size: 14px;
            color: #aaa;
        }

        form input[type="text"],
        form input[type="file"],
        form textarea {
            width: 100%;
            padding: 10px;
            background: #222;
            border: 1px solid #444;
            border-radius: 5px;
            color: #fff;
            font-size: 14px;
        }

        form textarea {
            resize: vertical;
        }

        .profile-preview {
            text-align: center;
            margin-top: 20px;
        }

        .profile-preview img {
            width: 100px;
            height: 100px;
            object-fit: cover;
            border-radius: 50%;
            border: 2px solid #333;
        }

        input[type="submit"] {
            margin-top: 25px;
            background-color: #3897f0;
            border: none;
            padding: 10px 20px;
            font-size: 14px;
            border-radius: 5px;
            color: white;
            cursor: pointer;
            width: 100%;
        }

        input[type="submit"]:hover {
            background-color: #2e7fd8;
        }
    </style>
</head>
<body>

<div class="edit-profile-container">
    <h2>Edit Profile</h2>

    <form action="update_profile.php" method="post" enctype="multipart/form-data">
        <label for="username">Username:</label>
        <input type="text" name="username" value="<?php echo htmlspecialchars($user['username']); ?>" required>

        <label for="bio">Bio:</label>
        <textarea name="bio" rows="3"><?php echo htmlspecialchars($user['bio'] ?? ''); ?></textarea>

        <label for="city">City:</label>
        <input type="text" name="city" value="<?php echo htmlspecialchars($user['city'] ?? ''); ?>">

        <label for="profile_picture">Profile Picture:</label>
        <input type="file" name="profile_picture" accept="image/*">

        <?php if (!empty($user['profile_picture'])): ?>
        <div class="profile-preview">
            <img src="<?php echo htmlspecialchars($user['profile_picture']); ?>" alt="Current Profile Picture">
        </div>
        <?php endif; ?>

        <input type="submit" value="Save Changes">
    </form>
</div>

</body>
</html>
