<?php
session_start();
require_once('config.php');

$user_id = $_SESSION['user_id'] ?? null;

$sql = "SELECT posts.*, users.username, users.is_verified, users.id as user_id
        FROM posts 
        JOIN users ON posts.user_id = users.id 
        ORDER BY posts.created_at DESC";

$result = $conn->query($sql);
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>Feed</title>
  <style>
    body {
      background: #000;
      color: #fff;
      font-family: Arial, sans-serif;
      margin: 0;
      padding: 0;
    }
    a { color: inherit; text-decoration: none; }

    .navbar, .bottom-nav {
      position: fixed; width: 100%; background: #111;
      display: flex; justify-content: space-between; align-items: center;
      padding: 10px 20px; z-index: 1000;
    }
    .navbar { top: 0; border-bottom: 1px solid #222; }
    .bottom-nav { bottom: 0; border-top: 1px solid #222; justify-content: space-around; }

    .navbar-logo { font-weight: bold; font-size: 18px; }
    .navbar-icons a, .bottom-nav a { font-size: 18px; }

    .main-container {
      max-width: 600px;
      margin: 70px auto 70px;
      padding: 0 15px;
    }

    .post {
      background: #111;
      border: 1px solid #222;
      padding: 15px;
      margin-bottom: 20px;
      border-radius: 8px;
    }

    .post strong a {
      color: #fff;
      text-decoration: none;
    }

    .post img, .post video {
      width: 100%;
      margin-top: 10px;
      border-radius: 6px;
    }

    .interactions {
      margin-top: 10px;
      font-size: 14px;
      color: #aaa;
    }

    .verified-badge {
      height: 16px;
      vertical-align: middle;
      margin-left: 5px;
    }

    .caption {
      margin-top: 10px;
      font-size: 14px;
      color: #ddd;
    }

    small {
      display: block;
      margin-top: 8px;
      color: #777;
    }
  </style>
</head>
<body>

<!-- Top Navbar -->
<div class="navbar">
  <div class="navbar-logo">InstaClone</div>
  <div class="navbar-icons">
    <a href="feed.php">🏠</a>
    <a href="search.php">🔍</a>
    <a href="upload.php">➕</a>
    <a href="profile.php?id=<?php echo $user_id; ?>">👤</a>
  </div>
</div>

<div class="main-container">
  <?php if ($result && $result->num_rows > 0): ?>
    <?php while($post = $result->fetch_assoc()): ?>
      <div class="post">
        <strong>
          <a href="profile.php?id=<?php echo $post['user_id']; ?>">
            <?php echo htmlspecialchars($post['username']); ?>
          </a>
          <?php if (!empty($post['is_verified'])): ?>
            <img src="verified_badge.png" alt="Verified" class="verified-badge">
          <?php endif; ?>
        </strong><br>

        <?php
        $media = '';
        if ($post['post_type'] === 'image' && !empty($post['image_path'])) {
          $media = htmlspecialchars($post['image_path']);
        } elseif ($post['post_type'] === 'video' && !empty($post['video_path'])) {
          $media = htmlspecialchars($post['video_path']);
        }

        if (!empty($media)) {
          echo (strpos($media, '.mp4') !== false)
            ? "<video src='{$media}' controls></video>"
            : "<img src='{$media}' alt='Post media'>";
        }

        if (!empty($post['caption'])) {
          echo "<div class='caption'>" . nl2br(htmlspecialchars($post['caption'])) . "</div>";
        }

        if (!empty($post['created_at'])) {
          echo "<small>Posted on " . date('F j, Y, g:i a', strtotime($post['created_at'])) . "</small>";
        }

        echo "<div class='interactions'>❤️ <span>0 likes</span> | 💬 <span>0 comments</span></div>";
        ?>
      </div>
    <?php endwhile; ?>
  <?php else: ?>
    <div class="post">
      <p>No posts to show.</p>
    </div>
  <?php endif; ?>
</div>

<!-- Bottom Navbar -->
<div class="bottom-nav">
  <a href="feed.php">🏠</a>
  <a href="search.php">🔍</a>
  <a href="upload.php">➕</a>
  <a href="profile.php?id=<?php echo $user_id; ?>">👤</a>
</div>

</body>
</html>
