<?php
session_start();
require_once('config.php');

$profile_user_id = $_GET['id'] ?? null;
if (!$profile_user_id) die("Profile not found.");
$user_id = $_SESSION['user_id'] ?? null;

// Fetch user
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $profile_user_id);
$stmt->execute();
$user = $stmt->get_result()->fetch_assoc();
if (!$user) die("User not found.");

$profile_pic = $user['profile_picture'] ?: 'default-avatar.png';

// Counts
$post_count = $conn->query("SELECT COUNT(*) as total FROM posts WHERE user_id = $profile_user_id")->fetch_assoc()['total'] ?? 0;
$followers = $conn->query("SELECT COUNT(*) as total FROM followers WHERE followed_id = $profile_user_id")->fetch_assoc()['total'] ?? 0;
$following = $conn->query("SELECT COUNT(*) as total FROM followers WHERE follower_id = $profile_user_id")->fetch_assoc()['total'] ?? 0;

$is_following = false;
if ($user_id && $user_id != $profile_user_id) {
    $check = $conn->prepare("SELECT 1 FROM followers WHERE follower_id = ? AND followed_id = ?");
    $check->bind_param("ii", $user_id, $profile_user_id);
    $check->execute();
    $is_following = $check->get_result()->num_rows > 0;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title><?php echo htmlspecialchars($user['username']); ?> • Profile</title>
  <style>
    body { margin: 0; background: #000; color: #fff; font-family: Arial; }
    a { color: inherit; text-decoration: none; }

    .navbar, .bottom-nav {
      position: fixed; width: 100%; background: #111;
      display: flex; justify-content: space-between; align-items: center;
      padding: 10px 20px; z-index: 1000;
    }
    .navbar { top: 0; border-bottom: 1px solid #222; }
    .bottom-nav { bottom: 0; border-top: 1px solid #222; justify-content: space-around; }

    .navbar-logo { font-weight: bold; font-size: 18px; }
    .navbar-icons a, .bottom-nav a { font-size: 18px; }

    .profile-header {
      display: flex; align-items: center; padding: 90px 20px 20px;
      max-width: 800px; margin: auto; gap: 30px;
    }
    .profile-picture {
      width: 100px; height: 100px; border-radius: 50%;
      object-fit: cover; border: 2px solid #333;
    }
    .profile-info { flex: 1; }
    .profile-info h2 { margin: 0 0 10px; }
    .profile-info .stats { display: flex; gap: 20px; margin-bottom: 10px; color: #ccc; }
    .bio { font-size: 14px; color: #aaa; }

    .profile-actions input, .profile-actions a {
      padding: 6px 14px; font-size: 14px; border: 1px solid #555;
      background: #111; color: #fff; border-radius: 4px; cursor: pointer;
    }

    .post-grid {
      display: grid; grid-template-columns: repeat(auto-fill, minmax(150px, 1fr));
      gap: 5px; max-width: 800px; margin: 20px auto; padding: 0 15px;
    }
    .post-grid img {
      width: 100%; height: 150px; object-fit: cover;
      background: #111; border: 1px solid #222; cursor: pointer;
    }

    .modal {
      display: none; position: fixed; top: 0; left: 0;
      width: 100%; height: 100%; background: rgba(0,0,0,0.85); z-index: 999;
    }
    .modal-content {
      max-width: 500px; background: #111; margin: 80px auto; padding: 20px;
      border-radius: 8px; color: #fff; text-align: center;
    }
    .modal-content img, .modal-content video {
      width: 100%; border-radius: 6px;
    }
    .close { float: right; font-size: 28px; cursor: pointer; color: #aaa; }
    .modal-caption { margin: 15px 0; font-size: 15px; color: #ddd; }
    .modal-meta, .modal-comments { font-size: 13px; color: #bbb; text-align: left; margin-top: 10px; }

    #likeBtn { cursor: pointer; background: none; border: none; color: #f44; font-size: 18px; }
    #commentInput {
      width: 100%; padding: 8px; margin-top: 10px;
      background: #222; color: #fff; border: none; border-radius: 4px;
    }
  </style>
</head>
<body>

<div class="navbar">
  <div class="navbar-logo">InstaClone</div>
  <div class="navbar-icons">
    <a href="feed.php">🏠</a>
    <a href="search.php">🔍</a>
    <a href="upload.php">➕</a>
    <a href="profile.php?id=<?php echo $user_id; ?>">👤</a>
  </div>
</div>

<div class="profile-header">
  <img src="<?php echo htmlspecialchars($profile_pic); ?>" class="profile-picture">
  <div class="profile-info">
    <h2><?php echo htmlspecialchars($user['username']); ?></h2>
    <div class="stats">
      <div><strong><?php echo $post_count; ?></strong> posts</div>
      <div><strong><?php echo $followers; ?></strong> followers</div>
      <div><strong><?php echo $following; ?></strong> following</div>
    </div>
    <div class="bio"><?php echo htmlspecialchars($user['bio'] ?? '') . "<br>" . htmlspecialchars($user['city'] ?? ''); ?></div>
    <div class="profile-actions">
      <?php if ($user_id && $user_id != $profile_user_id): ?>
        <form method="post" action="follow_unfollow.php">
          <input type="hidden" name="followed_id" value="<?php echo $profile_user_id; ?>">
          <input type="submit" value="<?php echo $is_following ? 'Unfollow' : 'Follow'; ?>">
        </form>
      <?php elseif ($user_id == $profile_user_id): ?>
        <a href="edit_profile.php">Edit Profile</a>
      <?php endif; ?>
    </div>
  </div>
</div>

<div class="post-grid">
<?php
$stmt = $conn->prepare("
  SELECT p.id, p.image_path, p.video_path, p.post_type, p.caption,
  (SELECT COUNT(*) FROM likes WHERE post_id = p.id) as like_count,
  (SELECT COUNT(*) FROM comments WHERE post_id = p.id) as comment_count
  FROM posts p WHERE user_id = ? ORDER BY created_at DESC
");
$stmt->bind_param("i", $profile_user_id);
$stmt->execute();
$posts = $stmt->get_result();

while ($p = $posts->fetch_assoc()):
  $media = $p['image_path'] ?: $p['video_path'];
  echo "<img src='" . htmlspecialchars($media) . "'
    class='grid-post'
    data-id='{$p['id']}'
    data-caption='" . htmlspecialchars($p['caption']) . "'
    data-likes='{$p['like_count']}'
    data-comments='{$p['comment_count']}'
    data-type='{$p['post_type']}'>";
endwhile;
?>
</div>

<div class="bottom-nav">
  <a href="feed.php">🏠</a>
  <a href="search.php">🔍</a>
  <a href="upload.php">➕</a>
  <a href="profile.php?id=<?php echo $user_id; ?>">👤</a>
</div>
<!-- Post Modal -->
<div id="postModal" class="modal">
  <div class="modal-content">
    <span class="close" onclick="modal.style.display='none'">&times;</span>
    <div id="modalMediaContainer"></div>
    <div class="modal-caption" id="modalCaption"></div>
    <div class="modal-meta">
      <button id="likeBtn">❤️</button>
      <span id="modalLikes">0</span> likes • 
      💬 <span id="modalComments">0</span> comments
    </div>
    <div class="modal-comments" id="modalCommentsList"></div>
    <?php if ($user_id): ?>
      <form id="commentForm">
        <input type="hidden" id="modalPostId">
        <input type="text" id="commentInput" placeholder="Add a comment...">
      </form>
    <?php endif; ?>
    <div id="likeUsers" style="margin-top:10px; font-size:12px; color:#888;"></div>
  </div>
</div>

<script>
const modal = document.getElementById("postModal");
const modalMedia = document.getElementById("modalMediaContainer");
const modalCaption = document.getElementById("modalCaption");
const modalLikes = document.getElementById("modalLikes");
const modalComments = document.getElementById("modalComments");
const modalCommentsList = document.getElementById("modalCommentsList");
const modalPostId = document.getElementById("modalPostId");
const likeBtn = document.getElementById("likeBtn");
const commentInput = document.getElementById("commentInput");
const commentForm = document.getElementById("commentForm");
const likeUsers = document.getElementById("likeUsers");

document.querySelectorAll(".grid-post").forEach(img => {
  img.onclick = () => {
    modal.style.display = "block";
    const id = img.dataset.id;
    const isVideo = img.dataset.type === 'video';

    modalPostId.value = id;
    modalCaption.textContent = img.dataset.caption;
    modalLikes.textContent = img.dataset.likes;
    modalComments.textContent = img.dataset.comments;

    modalMedia.innerHTML = isVideo
      ? `<video src="${img.src}" controls></video>`
      : `<img src="${img.src}">`;

    // Load comments
    fetch(`load_comments.php?post_id=${id}`)
      .then(res => res.json())
      .then(data => {
        modalCommentsList.innerHTML = "";
        data.forEach(c => {
          const div = document.createElement("div");
          div.textContent = `${c.username}: ${c.comment}`;
          modalCommentsList.appendChild(div);
        });
      });

    // Load likes
    fetch(`load_likes.php?post_id=${id}`)
      .then(res => res.json())
      .then(data => {
        likeUsers.textContent = data.length ? "Liked by " + data.join(", ") : "";
      });
  };
});

// Like toggle
likeBtn.onclick = () => {
  const id = modalPostId.value;
  fetch("toggle_like.php", {
    method: "POST",
    headers: { "Content-Type": "application/x-www-form-urlencoded" },
    body: `post_id=${id}`
  }).then(res => res.text()).then(result => {
    if (result === "liked") {
      modalLikes.textContent = parseInt(modalLikes.textContent) + 1;
    } else if (result === "unliked") {
      modalLikes.textContent = Math.max(0, parseInt(modalLikes.textContent) - 1);
    }
  });
};

// Comment submit
if (commentForm) {
  commentForm.onsubmit = e => {
    e.preventDefault();
    const id = modalPostId.value;
    const text = commentInput.value.trim();
    if (!text) return;

    fetch("submit_comment.php", {
      method: "POST",
      headers: { "Content-Type": "application/x-www-form-urlencoded" },
      body: `post_id=${id}&comment=${encodeURIComponent(text)}`
    }).then(res => res.text()).then(() => {
      commentInput.value = "";
      document.querySelector(`.grid-post[data-id="${id}"]`).click(); // Reload modal
    });
  };
}

window.onclick = e => {
  if (e.target == modal) modal.style.display = "none";
};
</script>

</body>
</html>
