<?php
session_start();
require_once 'includes/db_connect.php';

if (!isset($_SESSION['user_id'])) {
    die("You must be logged in to search.");
}

$search_term = isset($_GET['search_term']) ? $_GET['search_term'] : '';
$users = [];

if (!empty($search_term)) {
    $sql = "SELECT * FROM users WHERE username LIKE ?";
    $stmt = $conn->prepare($sql);
    $search_param = "%" . $search_term . "%";
    $stmt->bind_param("s", $search_param);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result->num_rows > 0) {
        while ($row = $result->fetch_assoc()) {
            $users[] = $row;
        }
    }
}
?>

<!DOCTYPE html>
<html>
<head>
    <title>Search</title>
    <link rel="stylesheet" href="style.css">
</head>
<body>
    <div class="search-container">
        <h2>Search Users</h2>
        <form action="search.php" method="get">
            <input type="text" name="search_term" placeholder="Search by username" value="<?php echo htmlspecialchars($search_term); ?>">
            <input type="submit" value="Search">
        </form>

        <?php if (!empty($users)): ?>
            <div class="search-results">
                <?php foreach ($users as $user): ?>
                    <div class="user-item">
                        <?php if (!empty($user['profile_picture'])): ?>
                            <img src="<?php echo $user['profile_picture']; ?>" class="profile-pic">
                        <?php else: ?>
                            <div class="profile-pic placeholder"></div>
                        <?php endif; ?>
                        <a href="profile.php?user_id=<?php echo $user['id']; ?>"><?php echo $user['username']; ?></a>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php elseif (!empty($search_term)): ?>
            <p>No users found.</p>
        <?php endif; ?>
    </div>
</body>
</html>